@@ -199,7 +199,7 @@ class Catalog:
             if c['name'] == channel:
                 #If so, first remove all the bundles it contains
                 while len(c['entries']) > 0:
-                    self._remove_bundle_from_channel(c['entries'][0]['name'], channel)
+                    self.remove_bundle_from_channel(c['entries'][0]['name'], channel)
                 #Then, remove the channel
                 self.channels.remove(c)
                 log.info("Removed channel %s", channel)
@@ -214,7 +214,7 @@ class Catalog:
                     self.set_default_channel(latest_channel['name'])
     
     #Remove a bundle, unless that bundle is contained in another channel, then do nothing
-    def _remove_bundle_from_channel(self, bundle_name, channel_name):
+    def remove_bundle_from_channel(self, bundle_name, channel_name):
         #Initialize a boolean to track whether the bundle belongs to another channel
         multi_channel_bundle = False
         #Loop through all bundles in the object
@@ -416,4 +416,4 @@ class OperatorCatalog:
         ret = ''
         for operator_name in self.catalogs.keys():
             ret += f'{operator_name}: {str(self.catalogs[operator_name])}'
-        return ret
\ No newline at end of file
+        return ret
